@@ -31,7 +31,7 @@ import sys
 from requests.auth import AuthBase
 from time import gmtime, strftime
 
-if sys.version_info[0] == 3:
+if sys.version_info[0] >= 3:
     # python3
     from urllib.parse import urlparse, parse_qsl, urlunparse
 else:
@@ -72,7 +72,7 @@ class EdgeGridAuth(AuthBase):
     """
 
     def __init__(self, client_token, client_secret, access_token, 
-                 headers_to_sign=None, max_body=2048, testurl=None):
+                 headers_to_sign=None, max_body=2048):
         """Initialize authentication using the given parameters from the Luna Manage APIs
            Interface:
 
@@ -83,7 +83,6 @@ class EdgeGridAuth(AuthBase):
             the signature.  This will be provided by specific APIs. (default [])
         :param max_body: Maximum content body size for POST requests. This will be provided by
             specific APIs. (default 2048)
-        :param testurl: Use this value for method and host portion of URL when signing.
 
         """
         self.client_token = client_token
@@ -94,7 +93,27 @@ class EdgeGridAuth(AuthBase):
         else:
             self.headers_to_sign = []
         self.max_body = max_body
-        self.testurl = testurl
+
+    @staticmethod
+    def from_edgerc(filename, section='default'):
+        """Returns an EdgeGridAuth object from the configuration from the given section of the 
+           given edgerc file.
+
+        :param filename: path to the edgerc file
+        :param section: the section to use (this is the [bracketed] part of the edgerc, 
+            default is 'default')
+
+        """
+        from .edgerc import EdgeRc 
+        rc = EdgeRc(filename)
+
+        return EdgeGridAuth(
+            client_token=rc.get(section, 'client_token'),
+            client_secret=rc.get(section, 'client_secret'),
+            access_token=rc.get(section, 'access_token'),
+            headers_to_sign=rc.getlist(section, 'headers_to_sign'),
+            max_body=rc.getint(section, 'max_body')
+        )
 
     def make_signing_key(self, timestamp):
         signing_key = base64_hmac_sha256(timestamp, self.client_secret)
@@ -110,7 +129,7 @@ class EdgeGridAuth(AuthBase):
             "%s:%s" % (h, spaces_re.sub(' ', r.headers[h].strip()))
             for h in self.headers_to_sign if h in r.headers
         ])
-        
+
     def make_content_hash(self, r):
         content_hash = ""
         prepared_body = (r.body or '')
@@ -132,18 +151,17 @@ class EdgeGridAuth(AuthBase):
         return content_hash
 
     def make_data_to_sign(self, r, auth_header):
-        if self.testurl:
-            testparts = urlparse(self.testurl)
-            requestparts = urlparse(r.url)
-            url = urlunparse(testparts[0:2] + requestparts[2:])
+        parsed_url = urlparse(r.url)
+
+        if (r.headers.get('Host', False)):
+            netloc = r.headers['Host']
         else:
-            url = r.url
+            netloc = parsed_url.netloc
 
-        parsed_url = urlparse(url)
         data_to_sign = '\t'.join([
             r.method,
             parsed_url.scheme,
-            parsed_url.netloc,
+            netloc,
             # Note: relative URL constraints are handled by requests when it sets up 'r'
             parsed_url.path + ('?' + parsed_url.query if parsed_url.query else ""),
             self.canonicalize_headers(r),
@@ -168,7 +186,7 @@ class EdgeGridAuth(AuthBase):
         ]
         auth_header = "EG1-HMAC-SHA256 " + ';'.join([ "%s=%s" % kvp for kvp in kvps ]) + ';'
         logger.debug('unsigned authorization header: %s', auth_header)
-        
+
         signed_auth_header = auth_header + \
             'signature=' + self.sign_request(r, timestamp, auth_header)
 
@@ -181,4 +199,3 @@ class EdgeGridAuth(AuthBase):
 
         r.headers['Authorization'] = self.make_auth_header(r, timestamp, nonce)
         return r
-
